# Project goals

- a minimal interface to arbitrary REST API having an OpenAPI description
- do not assume anything about what future users will need

## How the goals are achieved

- lots of functional code
- lots of end-to-end testing
- small code base
- not a lot of type annotations

